==> haskell-csv-0.1.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-JHiDO18E4reI6zYI6iizmR
key: csv-0.1.2-JHiDO18E4reI6zYI6iizmR
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
author: Jaap Weel <weel@ugcs.caltech.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.CSV
abi: 5c0ac6d6a442afdf97e2420bc27e16db
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/csv-0.1.2
hs-libraries: HScsv-0.1.2-JHiDO18E4reI6zYI6iizmR
depends:
    base-4.10.1.0 filepath-1.4.1.2 parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             parsec-3.1.11-1k1VJixRpBgKJgdIEz2OP7=de60442ea6c5324e39bc534a733c07dd
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-csv-0.1.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-csv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: csv
version: 0.1.2
id: csv-0.1.2-I4gcangUQPN5j1xlMcytF8
key: csv-0.1.2-I4gcangUQPN5j1xlMcytF8
license: MIT
copyright: Jaap Weel, 2007
maintainer: Jaap Weel <weel@ugcs.caltech.edu>
synopsis: CSV loader and dumper
description:
    CSV loader and dumper
    .
    This library parses and dumps documents that are formatted
    according to RFC 4180, \"The common Format and MIME Type for
    Comma-Separated Values (CSV) Files\". This format is used, among
    many other things, as a lingua franca for spreadsheets, and for
    certain web services.
category: Text
author: Jaap Weel <weel@ugcs.caltech.edu>
exposed: True
indefinite: False
exposed-modules:
    Text.CSV
abi: 2d03fd6745e50a614262bbdc40354308
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/csv-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/csv-0.1.2
hs-libraries: HScsv-0.1.2-I4gcangUQPN5j1xlMcytF8
depends:
    base-4.10.1.0 filepath-1.4.1.2
    parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             parsec-3.1.13.0-lnA0oAxTgL1KjACiBdQ3F=688f5e7444a80128e4a1c39bd128d195
haddock-interfaces: /usr/share/doc/haskell-csv/html/csv.haddock
haddock-html: /usr/share/doc/haskell-csv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
